summaryrefslogtreecommitdiff
path: root/tests/regression-funcs.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tests/regression-funcs.sh')
-rwxr-xr-xtests/regression-funcs.sh32
1 files changed, 16 insertions, 16 deletions
diff --git a/tests/regression-funcs.sh b/tests/regression-funcs.sh
index 979157bcf9..bba189092b 100755
--- a/tests/regression-funcs.sh
+++ b/tests/regression-funcs.sh
@@ -1,6 +1,6 @@
#!/bin/sh
#
# common regression functions for ffmpeg
#
#
@@ -18,7 +18,7 @@ this="$test.$test_ref"
outfile="$datadir/$test_ref/"
# various files
-ffmpeg="$target_exec ${target_path}/ffmpeg"
+avconv="$target_exec ${target_path}/avconv"
tiny_psnr="tests/tiny_psnr"
raw_src="${target_path}/$raw_src_dir/%02d.pgm"
raw_dst="$datadir/$this.out.yuv"
@@ -43,23 +43,23 @@ echov(){
. $(dirname $0)/md5.sh
-FFMPEG_OPTS="-v 0 -y"
+AVCONV_OPTS="-v 0 -y"
COMMON_OPTS="-flags +bitexact -idct simple -sws_flags +accurate_rnd+bitexact"
DEC_OPTS="$COMMON_OPTS -threads $threads"
ENC_OPTS="$COMMON_OPTS -threads 1 -dct fastint"
-run_ffmpeg()
+run_avconv()
{
- $echov $ffmpeg $FFMPEG_OPTS $*
- $ffmpeg $FFMPEG_OPTS $*
+ $echov $avconv $AVCONV_OPTS $*
+ $avconv $AVCONV_OPTS $*
}
-do_ffmpeg()
+do_avconv()
{
f="$1"
shift
set -- $* ${target_path}/$f
- run_ffmpeg $*
+ run_avconv $*
do_md5sum $f
if [ $f = $raw_dst ] ; then
$tiny_psnr $f $raw_ref
@@ -70,12 +70,12 @@ do_ffmpeg()
fi
}
-do_ffmpeg_nomd5()
+do_avconv_nomd5()
{
f="$1"
shift
set -- $* ${target_path}/$f
- run_ffmpeg $*
+ run_avconv $*
if [ $f = $raw_dst ] ; then
$tiny_psnr $f $raw_ref
elif [ $f = $pcm_dst ] ; then
@@ -85,32 +85,32 @@ do_ffmpeg_nomd5()
fi
}
-do_ffmpeg_crc()
+do_avconv_crc()
{
f="$1"
shift
- run_ffmpeg $* -f crc "$target_crcfile"
+ run_avconv $* -f crc "$target_crcfile"
echo "$f $(cat $crcfile)"
}
do_video_decoding()
{
- do_ffmpeg $raw_dst $DEC_OPTS $1 -i $target_path/$file -f rawvideo $ENC_OPTS -vsync 0 $2
+ do_avconv $raw_dst $DEC_OPTS $1 -i $target_path/$file -f rawvideo $ENC_OPTS -vsync 0 $2
}
do_video_encoding()
{
file=${outfile}$1
- do_ffmpeg $file $DEC_OPTS -f image2 -vcodec pgmyuv -i $raw_src $ENC_OPTS $2
+ do_avconv $file $DEC_OPTS -f image2 -vcodec pgmyuv -i $raw_src $ENC_OPTS $2
}
do_audio_encoding()
{
file=${outfile}$1
- do_ffmpeg $file $DEC_OPTS -ac 2 -ar 44100 -f s16le -i $pcm_src -ab 128k $ENC_OPTS $2
+ do_avconv $file $DEC_OPTS -ac 2 -ar 44100 -f s16le -i $pcm_src -ab 128k $ENC_OPTS $2
}
do_audio_decoding()
{
- do_ffmpeg $pcm_dst $DEC_OPTS -i $target_path/$file -sample_fmt s16 -f wav
+ do_avconv $pcm_dst $DEC_OPTS -i $target_path/$file -sample_fmt s16 -f wav
}
@@ -1,6 +1,6 @@
#!/bin/sh
#
-# common regression functions for ffmpeg
+# common regression functions for avconv
#
#